## v0.3.0 (2024-12-14)

### Feat

- **logging**: add debug and info logs for S3, DynamoDB, and DataTransformer operations

### Fix

- **python-deps**: upgraded python dependencies with uv sync --upgrade

## v0.2.1 (2024-12-10)

### Fix

- **ci**: updated uv sync --locked to uv sync --frozen

## v0.2.0 (2024-12-09)

### Feat

- **processor**: implement multiprocessing to decompress downloaded data from s3 faster

## v0.1.1 (2024-12-05)

## v0.1.0 (2024-12-05)
